Bundle

Struct Bundle 

pub struct Bundle { /* private fields */ }
OCI bundle representation.

A bundle encapsulates an OCI runtime configuration and its associated root filesystem.

Implementations

Source

impl Bundle

pub fn load<P: AsRef<Path>>(path: P) -> Result<Self>

Load an OCI bundle from a directory.

This reads and validates the config.json file and checks that the bundle structure is valid.

pub fn create<P: AsRef<Path>>(path: P, spec: Spec) -> Result<Self>

Create a new bundle from an existing spec.

This creates the bundle directory structure and writes the config.json.

pub fn create_default<P: AsRef<Path>>(path: P) -> Result<Self>

Create a bundle with default Linux configuration.

pub fn path(&self) -> &Path

Get the bundle directory path.

pub const fn spec(&self) -> &Spec

Get the OCI specification.

pub const fn spec_mut(&mut self) -> &mut Spec

Get mutable reference to the OCI specification.

pub fn config_path(&self) -> PathBuf

Get the config.json path.

pub fn rootfs_path(&self) -> PathBuf

Get the root filesystem path.

Returns the resolved absolute path to the rootfs.

pub fn rootfs_exists(&self) -> bool

Check if the rootfs exists.

pub fn rootfs_readonly(&self) -> bool

Check if the rootfs is configured as read-only.

pub fn validate(&self) -> Result<()>

Validate the bundle structure.

pub fn save(&self) -> Result<()>

Save any modifications to the spec back to config.json.

pub fn update_spec(&mut self, spec: Spec) -> Result<()>

Update the spec and save.