BundleBuilder

Struct BundleBuilder 

pub struct BundleBuilder { /* private fields */ }
Bundle builder for creating new bundles.

Implementations

Source

impl BundleBuilder

pub fn new() -> Self

Create a new bundle builder with default Linux spec.

pub const fn with_spec(spec: Spec) -> Self

Create a new bundle builder with a custom spec.

pub fn hostname(self, hostname: impl Into<String>) -> Self

Set the hostname.

pub fn args(self, args: Vec<String>) -> Self

Set the process arguments.

pub fn env(self, env: Vec<String>) -> Self

Set the process environment.

pub fn add_env(self, key: impl Into<String>, value: impl Into<String>) -> Self

Add an environment variable.

pub fn cwd(self, cwd: impl Into<String>) -> Self

Set the working directory.

pub const fn user(self, uid: u32, gid: u32) -> Self

Set the user.

pub fn rootfs(self, path: impl Into<String>) -> Self

Set the rootfs path.

pub const fn readonly_rootfs(self, readonly: bool) -> Self

Set rootfs as read-only.

pub const fn terminal(self, terminal: bool) -> Self

Enable terminal.

pub fn annotation( self, key: impl Into<String>, value: impl Into<String>, ) -> Self

Add an annotation.

pub fn mount(self, mount: Mount) -> Self

Add a mount.

pub fn build<P: AsRef<Path>>(self, path: P) -> Result<Bundle>

Build the bundle at the specified path.

pub fn into_spec(self) -> Spec

Get the spec without building.