pub struct Spec {
pub oci_version: String,
pub root: Option<Root>,
pub process: Option<Process>,
pub hostname: Option<String>,
pub domainname: Option<String>,
pub mounts: Vec<Mount>,
pub hooks: Option<Hooks>,
pub annotations: HashMap<String, String>,
pub linux: Option<Linux>,
}Expand description
OCI runtime configuration (config.json).
This is the main configuration structure that defines how a container should be created and run according to the OCI runtime specification.
Fields
oci_version: StringOCI specification version (SemVer 2.0.0 format).
REQUIRED field.
root: Option<Root>Container’s root filesystem.
process: Option<Process>Container process to run.
hostname: Option<String>Container hostname.
domainname: Option<String>Container domain name.
mounts: Vec<Mount>Additional mounts beyond the root filesystem.
hooks: Option<Hooks>Lifecycle hooks.
annotations: HashMap<String, String>Arbitrary metadata annotations.
linux: Option<Linux>Linux-specific configuration.
Implementations
Sourceimpl Spec
impl Spec
Sourcepub fn default_linux() -> Self
pub fn default_linux() -> Self
Create a default spec for Linux containers.